@@ -3,10 +3,8 @@
 // See the LICENSE file in the project root for more information.
 
 using Cake.Core;
-using Cake.Core.Configuration;
 using Cake.Core.Diagnostics;
 using Cake.Core.IO;
-using Cake.Core.Tooling;
 
 namespace Cake.Common.Tools.SpecFlow
 {
